pub struct Bordered<'a> { /* private fields */ }Expand description
A simple bordered container with a title. Renders a block border and exposes the inner area for composing other widgets.
Implementations
Sourceimpl<'a> Bordered<'a>
impl<'a> Bordered<'a>
Sourcepub fn new(title: impl Into<Cow<'a, str>>) -> Self
pub fn new(title: impl Into<Cow<'a, str>>) -> Self
Creates a bordered container with the given title.
Sourcepub fn palette(self, palette: AislingPalette) -> Self
pub fn palette(self, palette: AislingPalette) -> Self
Sets the color palette.
Sourcepub fn render_inner(&self, buf: &mut Buffer, area: Rect) -> Rect
pub fn render_inner(&self, buf: &mut Buffer, area: Rect) -> Rect
Renders the border and returns the inner content area.