List

Struct List 

pub struct List<'a> { /* private fields */ }
A scrollable list with item selection highlighting.

Implementations

Source

impl<'a> List<'a>

pub fn new() -> Self

Creates an empty list.

pub fn item(self, item: impl Into<Cow<'a, str>>) -> Self

Adds an item to the list.

pub fn items<I, S>(self, items: I) -> Self
where I: IntoIterator<Item = S>, S: Into<Cow<'a, str>>,

Replaces all items.

pub fn selected(self, index: Option<usize>) -> Self

Sets the selected index.

pub fn scroll_offset(self, offset: u16) -> Self

Sets the scroll offset from the top.

pub fn tick(self, tick: u64) -> Self

Sets the animation tick.

pub fn palette(self, palette: AislingPalette) -> Self

Sets the color palette.

pub fn block(self, block: Block<'a>) -> Self

Adds a block around the list.

pub fn render_with_interaction( &self, frame: &mut Frame<'_>, id: impl Into<WidgetId>, area: Rect, )

Renders into a Scrin frame and registers hit regions for visible items.

pub fn hit_regions(&self, id: impl Into<WidgetId>, area: Rect) -> Vec<HitRegion>

Builds Scrin interaction metadata for the visible list items.

pub fn selectable_spans( &self, id: impl Into<WidgetId>, area: Rect, ) -> Vec<SelectableSpan>

Builds selectable spans for the visible list item labels.

pub fn scroll_region( &self, id: impl Into<WidgetId>, area: Rect, ) -> Option<(Rect, usize, Vec<ScrollRowHit>)>

Builds Scrin scroll-region metadata for visible list rows.

pub fn item_count(&self) -> usize

Returns the number of items.