AislingTerminalExt

Trait AislingTerminalExt 

pub trait AislingTerminalExt {
    // Required methods
    fn render_widget_buffer<W>(&self, widget: W) -> Buffer
       where W: Widget;
    fn present_widget_buffer_timed<W>(
        &mut self,
        widget: W,
    ) -> Result<FrameTiming>
       where W: Widget;
    fn present_widget_buffer_areas_timed<W>(
        &mut self,
        widget: W,
        areas: &[Rect],
    ) -> Result<FrameTiming>
       where W: Widget;
}
Convenience methods for Scrin 0.1.84’s direct buffer presentation path.

Required Methods

fn render_widget_buffer<W>(&self, widget: W) -> Buffer
where W: Widget,

Renders a widget into a buffer sized to the terminal.

fn present_widget_buffer_timed<W>(&mut self, widget: W) -> Result<FrameTiming>
where W: Widget,

Renders a widget into a full-size buffer and presents it without a frame closure.

fn present_widget_buffer_areas_timed<W>( &mut self, widget: W, areas: &[Rect], ) -> Result<FrameTiming>
where W: Widget,

Renders a widget into a full-size buffer and presents selected areas only.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl AislingTerminalExt for Terminal

Source

fn render_widget_buffer<W>(&self, widget: W) -> Buffer
where W: Widget,

Source

fn present_widget_buffer_timed<W>(&mut self, widget: W) -> Result<FrameTiming>
where W: Widget,

Source

fn present_widget_buffer_areas_timed<W>( &mut self, widget: W, areas: &[Rect], ) -> Result<FrameTiming>
where W: Widget,

Implementors